AshAi.Tool.Execution (ash_ai v0.6.1)

Copy Markdown View Source

Executes Ash actions from tool call arguments.

Summary

Functions

Executes a tool with the given arguments and context.

Functions

run(tool, client_arguments, context)

Executes a tool with the given arguments and context.

Returns:

  • {:ok, json_result, raw_result} for successful tool calls
  • {:error, json_error} for execution failures