Event data passed to the on_tool_start callback used by AshAi.ToolLoop.
Contains information about the tool execution that is about to begin.
Event data passed to the on_tool_start callback used by AshAi.ToolLoop.
Contains information about the tool execution that is about to begin.